@@ -40,14 +40,10 @@
 #include <sys/types.h>
 #include <sys/fcntl.h>
 #include <sys/termios.h>
-#include <sys/wait.h>
 #include <dirent.h>
 #include <unistd.h>
 #include <stdio.h>
 #include <string.h>
-#ifndef G_OS_WIN32
-#include <pwd.h>
-#endif
 
 #include <gio/gio.h>
 #include <glib/gi18n.h>
@@ -55,6 +51,13 @@
 #include <glib/gstdio.h>
 #include <gtk/gtk.h>
 
+#ifndef G_OS_WIN32
+#include <pwd.h>
+#else
+#define WIN32_MEAN_AND_LEAN
+#include <windows.h>
+#endif
+
 #include <libanjuta/anjuta-utils.h>
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/interfaces/ianjuta-editor-cell.h>
@@ -582,7 +585,7 @@ anjuta_util_package_is_installed (const gchar * package, gboolean show)
 	}
 
 
-	if (WIFEXITED (exit_status) && WEXITSTATUS (exit_status) == 0)
+	if (g_spawn_check_exit_status (exit_status, NULL))
 		return TRUE;
 
 	if (show)
@@ -761,7 +764,8 @@ anjuta_util_get_real_path (const gchar *path)
 	if (path != NULL)
 	{
 		gchar *result;
-#ifdef PATH_MAX
+#ifndef G_OS_WIN32
+#  ifdef PATH_MAX
 		gchar buf[PATH_MAX+1];
 
 		result = realpath (path, buf);
@@ -770,7 +774,7 @@ anjuta_util_get_real_path (const gchar *path)
 			*(buf + PATH_MAX) = '\0'; /* ensure a terminator */
 			return g_strdup (buf);
 		}
-#else
+#  else
 		char *buf;
 		/* the string returned by realpath should be cleaned with
 		   free(), not g_free() */
@@ -781,6 +785,32 @@ anjuta_util_get_real_path (const gchar *path)
 			free (buf);
 			return result;
 		}
+#  endif
+#else
+		char dummy;
+		int rc, len;
+
+		/* Get length of path */
+		rc = GetFullPathName (path, 1, &dummy, NULL);
+		if (rc == 0)
+		{
+			/* Weird failure */
+			return g_strdup (path);
+		}
+
+		len = rc + 1;
+		result = g_malloc (len);
+
+		/* Get the real path */
+		rc = GetFullPathName (path, len, result, NULL);
+		if (rc == 0 || rc > len)
+		{
+			/* Another weird failure */
+			g_free (result);
+			return g_strdup (path);
+		}
+
+		return result;
 #endif
 	}
 	return NULL;
@@ -1131,9 +1161,6 @@ anjuta_util_user_shell (void)
 gchar **
 anjuta_util_user_terminal (void)
 {
-/* FIXME: GSettings */
-#if 0
-	GConfClient *client;
 	gchar *terminal = NULL;
 	gchar **argv = NULL;
 	static const gchar *terms[] = {
@@ -1147,22 +1174,22 @@ anjuta_util_user_terminal (void)
 		NULL
 	};
 	const gchar **term;
+	GSettingsSchema *schema;
 
-	client = gconf_client_get_default ();
-	terminal = gconf_client_get_string (client, "/desktop/gnome/applications/terminal/exec", NULL);
-	g_object_unref (client);
+	schema = g_settings_schema_source_lookup (g_settings_schema_source_get_default (),
+	                                          "org.gnome.desktop.default-applications.terminal",
+	                                          TRUE);
 
-	if (terminal)
+	if (schema)
 	{
-		gchar *command_line;
-		gchar *exec_flag;
+		GSettings *settings = g_settings_new ("org.gnome.desktop.default-applications.terminal");
 
-		exec_flag = gconf_client_get_string (client, "/desktop/gnome/applications/terminal/exec_arg", NULL);
-		command_line = g_strconcat (terminal, " ", exec_flag, NULL);
+		argv = g_new0 (gchar *, 3);
+		argv[0] = g_settings_get_string (settings, "exec");
+		argv[1] = g_settings_get_string (settings, "exec-arg");
 
-		g_shell_parse_argv (command_line, NULL, &argv, NULL);
-		g_free (terminal);
-		g_free (exec_flag);
+		g_settings_schema_unref (schema);
+		g_object_unref (settings);
 
 		return argv;
 	}
@@ -1187,68 +1214,102 @@ anjuta_util_user_terminal (void)
 	argv[1] = g_strdup (term == &terms[2] ? "-x" : "-e");
 
 	return argv;
-#else
-	g_warning ("anjuta_util_user_terminal: Not implemented");
-	return NULL;
-#endif
 }
 
-pid_t
+static void
+close_pid (GPid pid,
+           gint status,
+           gpointer user_data)
+{
+	g_spawn_close_pid (pid);
+}
+
+GPid
 anjuta_util_execute_shell (const gchar *dir, const gchar *command)
 {
-	pid_t pid;
-	gchar *shell;
+	GPid pid;
+	gchar **argv;
+	GError *error = NULL;
 
 	g_return_val_if_fail (command != NULL, -1);
 
-	shell = anjuta_util_user_shell ();
-	pid = fork();
-	if (pid == 0)
+	argv = g_new0 (gchar *, 4);
+
+	argv[0] = anjuta_util_user_shell ();
+#ifndef G_OS_WIN32
+	argv[1] = g_strdup ("-c");
+#else
+	argv[2] = g_strdup ("/C");
+#endif
+	argv[3] = g_strdup (command);
+
+	if (dir)
+		anjuta_util_create_dir (dir);
+
+	if (!g_spawn_async (dir, argv, NULL,
+	                    G_SPAWN_SEARCH_PATH | G_SPAWN_DO_NOT_REAP_CHILD,
+	                    NULL, NULL, &pid, &error))
 	{
-		if(dir)
-		{
-			anjuta_util_create_dir (dir);
-			chdir (dir);
-		}
-		execlp (shell, shell, "-c", command, NULL);
-		g_warning (_("Cannot execute command: %s (using shell %s)\n"), command, shell);
-		_exit(1);
+		g_warning (_("Cannot execute command: %s (using shell %s): %s\n"),
+		           command, argv[0], error->message);
+		pid = 0;
 	}
-	if (pid < 0)
-		g_warning (_("Cannot execute command: %s (using shell %s)\n"), command, shell);
-	g_free (shell);
+
+	g_child_watch_add (pid, close_pid, NULL);
+
+	g_strfreev (argv);
 
 	// Anjuta will take care of child exit automatically.
 	return pid;
 }
 
-pid_t
+GPid
 anjuta_util_execute_terminal_shell (const gchar *dir, const gchar *command)
 {
-	pid_t pid;
+	GPid pid;
 	gchar *shell;
 	gchar **term_argv;
+	gchar **argv;
+	gint i;
+	GError *error = NULL;
 
 	g_return_val_if_fail (command != NULL, -1);
 
 	shell = anjuta_util_user_shell ();
 	term_argv = anjuta_util_user_terminal ();
-	pid = fork();
-	if (pid == 0)
+	argv = g_new0 (gchar *, g_strv_length (term_argv) + 4);
+
+	i = 0;
+	if (term_argv)
 	{
-		if(dir)
-		{
-			anjuta_util_create_dir (dir);
-			chdir (dir);
-		}
-		execlp (term_argv[0], term_argv[0], term_argv[1], shell, "-c", command, NULL);
-		g_warning (_("Cannot execute command: %s (using shell %s)\n"), command, shell);
-		_exit(1);
+		for (; term_argv [i]; i++)
+			argv[i] = term_argv[i];
 	}
-	if (pid < 0)
-		g_warning (_("Cannot execute command: %s (using shell %s)\n"), command, shell);
-	g_free (shell);
-	g_strfreev (term_argv);
+
+	argv[i++] = shell;
+#ifndef G_OS_WIN32
+	argv[i++] = g_strdup ("-c");
+#else
+	argv[i++] = g_strdup ("/C");
+#endif
+	argv[i++] = g_strdup (command);
+
+	if (dir)
+		anjuta_util_create_dir (dir);
+
+	if (!g_spawn_async (dir, argv, NULL,
+	                    G_SPAWN_SEARCH_PATH | G_SPAWN_DO_NOT_REAP_CHILD,
+	                    NULL, NULL, &pid, &error))
+	{
+		g_warning (_("Cannot execute command: %s (using shell %s): %s\n"),
+		           command, shell, error->message);
+		pid = 0;
+	}
+
+	g_child_watch_add (pid, close_pid, NULL);
+
+	g_strfreev (argv);
+	g_free (term_argv);
 
 	// Anjuta will take care of child exit automatically.
 	return pid;
