@@ -43,6 +43,9 @@
 #define LINE_ENTRY_WIDTH 7
 #define SEARCH_ENTRY_WIDTH 45
 
+/* Time spend to do search in the idle callback */
+#define CONTINUOUS_SEARCH_TIMEOUT 0.1
+
 struct _SearchBoxPrivate
 {
 	GtkWidget* grid;
@@ -74,8 +77,9 @@ struct _SearchBoxPrivate
 	gboolean highlight_all;	
 	gboolean regex_mode;
 	
-	gboolean highlight_complete;
-	
+	IAnjutaEditorCell *start_highlight;
+	IAnjutaEditorCell *end_highlight;
+	guint idle_id;
 };
 
 #ifdef GET_PRIVATE
@@ -104,6 +108,7 @@ on_document_changed (AnjutaDocman* docman, IAnjutaDocument* doc,
 	else
 	{
 		search_box->priv->current_editor = IANJUTA_EDITOR (doc);
+		if (search_box->priv->highlight_all) search_box_highlight_all (search_box);
 	}
 }
 
@@ -230,13 +235,14 @@ on_search_focus_out (GtkWidget* widget, GdkEvent* event, SearchBox* search_box)
 }
 
 
-
+/* Search regular expression in text, return TRUE and matching part as start and
+ * end integer position */
 static gboolean
-incremental_regex_search (const gchar* search_entry, const gchar* editor_text, gint * start_pos, gint * end_pos, gboolean search_forward)
+search_regex_in_text (const gchar* search_entry, const gchar* editor_text, gboolean search_forward, gint * start_pos, gint * end_pos)
 {
 	GRegex * regex;
 	GMatchInfo *match_info;
-	gboolean result;
+	gboolean found;
 	GError * err = NULL;
 
 	regex = g_regex_new (search_entry, 0, 0, &err);
@@ -248,9 +254,9 @@ incremental_regex_search (const gchar* search_entry, const gchar* editor_text, g
 		return FALSE;
 	}
 
-	result = g_regex_match (regex, editor_text, 0, &match_info);
+	found = g_regex_match (regex, editor_text, 0, &match_info);
 
-	if (result)
+	if (found)
 	{
 		if (search_forward)
 			g_match_info_fetch_pos(match_info, 0, start_pos, end_pos);
@@ -272,12 +278,124 @@ incremental_regex_search (const gchar* search_entry, const gchar* editor_text, g
 	if (match_info)
 		g_match_info_free (match_info);
 
-	return result;
+	return found;
 
 }
 
+/* Search string in text, return TRUE and matching part as start and
+ * end integer position */
+static gboolean
+search_str_in_text (const gchar* search_entry, const gchar* editor_text, gboolean case_sensitive, gint * start_pos, gint * end_pos)
+{
+	gboolean found;
+	
+	if (strlen (editor_text) >= strlen (search_entry))
+	{
+		gchar* selected_text_case;
+		gchar* search_text_case;
+
+		if (case_sensitive)
+		{
+			selected_text_case = g_strdup (editor_text);
+			search_text_case = g_strdup (search_entry);
+		}
+		else
+		{
+			selected_text_case = g_utf8_casefold (editor_text, strlen (editor_text));
+			search_text_case = g_utf8_casefold (search_entry, strlen (search_entry));
+		}
+
+		gchar* strstr = g_strstr_len (selected_text_case, -1, search_text_case);
+
+		if (strstr)
+		{
+			*start_pos = g_utf8_pointer_to_offset(selected_text_case, strstr);
+			*end_pos = g_utf8_pointer_to_offset(selected_text_case, strstr + strlen (search_entry));
+			found = TRUE;
+		}
+
+		g_free (selected_text_case);
+		g_free (search_text_case);
+	}
+
+	return found;
+}
+
+/* Search string in editor, return TRUE and matching part as start and
+ * end editor cell */
+static gboolean
+editor_search (IAnjutaEditor *editor,
+               const gchar *search_text, 
+               gboolean case_sensitive,
+               gboolean search_forward,
+               gboolean regex_mode,
+               IAnjutaEditorCell* search_start,
+               IAnjutaEditorCell* search_end,
+               IAnjutaEditorCell** result_start,
+               IAnjutaEditorCell** result_end)
+{
+	gboolean found;
+
+	if (regex_mode)
+	{
+		gint start_pos;
+		gint end_pos;
+		gchar *text_to_search;
+
+		text_to_search = ianjuta_editor_get_text (editor,
+		                                          IANJUTA_ITERABLE (search_start),
+		                                          IANJUTA_ITERABLE (search_end), NULL);
+
+		found = search_regex_in_text (search_text, text_to_search, search_forward, &start_pos, &end_pos);
+
+		start_pos += ianjuta_iterable_get_position(IANJUTA_ITERABLE (search_start), NULL);
+		end_pos += ianjuta_iterable_get_position(IANJUTA_ITERABLE (search_start), NULL);
+
+		if (found && start_pos >= 0)
+		{
+			*result_start = IANJUTA_EDITOR_CELL (ianjuta_editor_get_start_position (editor,
+			                                                                        NULL));
+			*result_end = IANJUTA_EDITOR_CELL (ianjuta_editor_get_start_position (editor,
+			                                                                      NULL));
+
+			if (!ianjuta_iterable_set_position(IANJUTA_ITERABLE(*result_start), start_pos, NULL) ||
+				!ianjuta_iterable_set_position(IANJUTA_ITERABLE(*result_end), end_pos, NULL))
+			{
+				g_object_unref(*result_start);
+				g_object_unref(*result_end);
+				found = FALSE;
+			}
+		}
+
+		g_free(text_to_search);
+	}
+	else
+	{
+		if (search_forward)
+		{
+			found = ianjuta_editor_search_forward (IANJUTA_EDITOR_SEARCH (editor),
+			                                       search_text, case_sensitive,
+			                                       search_start, search_end,
+			                                       result_start,
+			                                       result_end, NULL);
+		}
+		else
+		{
+			found = ianjuta_editor_search_backward (IANJUTA_EDITOR_SEARCH (editor),
+			                                        search_text, case_sensitive,
+			                                        search_end, search_start,
+			                                        result_start,
+			                                        result_end, NULL);
+		}
+	}
+
+	return found;
+}
+
 gboolean
-search_box_incremental_search (SearchBox* search_box, gboolean search_forward,
+search_box_incremental_search (SearchBox* search_box,
+                               gboolean search_forward,
+                               gboolean search_next,
                                gboolean wrap)
 {
 	IAnjutaIterable* real_start;
@@ -335,56 +453,23 @@ search_box_incremental_search (SearchBox* search_box, gboolean search_forward,
      * selection starts with a match, look for next match.
 	 */
 	if (ianjuta_editor_selection_has_selection (selection,
-	                                            NULL))
+	                                            NULL) && search_next)
 	{
-		IAnjutaIterable* selection_start =
-			ianjuta_editor_selection_get_start (selection, NULL);
-
 		gchar* selected_text =
 			ianjuta_editor_selection_get (selection, NULL);
 
 		gint start_pos, end_pos;
 		gboolean selected_have_search_text = FALSE;
 
-		if (search_box->priv->regex_mode)
-		{
-			/* Always look for first match */
-			if (incremental_regex_search (search_text, selected_text, &start_pos, &end_pos, TRUE))
-			{
-				selected_have_search_text = TRUE;
-			}
-		}
-		else if (strlen (selected_text) >= strlen (search_text))
-		{
-			gchar* selected_text_case;
-			gchar* search_text_case;
-
-			if (search_box->priv->case_sensitive)
-			{
-				selected_text_case = g_strdup (selected_text);
-				search_text_case = g_strdup (search_text);
-			}
-			else
-			{
-				selected_text_case = g_utf8_casefold (selected_text, strlen (selected_text));
-				search_text_case = g_utf8_casefold (search_text, strlen (search_text));
-			}
-
-			gchar* strstr = g_strstr_len (selected_text_case, -1, search_text_case);
-
-			if (strstr)
-			{
-				start_pos = g_utf8_pointer_to_offset(selected_text_case, strstr);
-				end_pos = g_utf8_pointer_to_offset(selected_text_case, strstr + strlen (search_text));
-				selected_have_search_text = TRUE;
-			}
-
-			g_free (selected_text_case);
-			g_free (search_text_case);
-		}
+		selected_have_search_text = search_box->priv->regex_mode ?
+			search_regex_in_text (search_text, selected_text, TRUE, &start_pos, &end_pos) :
+			search_str_in_text (search_text, selected_text, search_box->priv->case_sensitive, &start_pos, &end_pos);
 
 		if (selected_have_search_text)
 		{
+			IAnjutaIterable* selection_start =
+				ianjuta_editor_selection_get_start (selection, NULL);
+
 			if (search_forward && start_pos == 0)
 			{
 				end_pos += ianjuta_iterable_get_position(IANJUTA_ITERABLE (selection_start), NULL);
@@ -397,81 +482,22 @@ search_box_incremental_search (SearchBox* search_box, gboolean search_forward,
 				ianjuta_iterable_set_position (IANJUTA_ITERABLE(search_end), start_pos, NULL);
 				ianjuta_iterable_first (IANJUTA_ITERABLE (search_start), NULL);
 			}
+			g_object_unref (selection_start);
 		}
 
 		g_free (selected_text);
-
-		g_object_unref (selection_start);
 	}
 
-	gboolean result_set = FALSE;
-
-	gint start_pos, end_pos;
-	gchar * text_to_search;
-	gboolean result;
-
-	if (!found)
-	{
-		/* Try searching in current position */
-		if (search_box->priv->regex_mode)
-		{
-			text_to_search = ianjuta_editor_get_text (search_box->priv->current_editor,
-				                                      IANJUTA_ITERABLE (search_start),
-				                                      IANJUTA_ITERABLE (search_end), NULL);
-
-			result = incremental_regex_search (search_text, text_to_search, &start_pos, &end_pos, search_forward);
-
-			start_pos += ianjuta_iterable_get_position(IANJUTA_ITERABLE (search_start), NULL);
-			end_pos += ianjuta_iterable_get_position(IANJUTA_ITERABLE (search_start), NULL);
-
-			if (result && start_pos >= 0)
-			{
-				result_start = IANJUTA_EDITOR_CELL (ianjuta_editor_get_start_position (search_box->priv->current_editor,
-					                                                                   NULL));
-				result_end = IANJUTA_EDITOR_CELL (ianjuta_editor_get_start_position (search_box->priv->current_editor,
-					                                                                 NULL));
-
-				if (ianjuta_iterable_set_position(IANJUTA_ITERABLE(result_start), start_pos, NULL) &&
-					ianjuta_iterable_set_position(IANJUTA_ITERABLE(result_end), end_pos, NULL))
-				{
-					found = TRUE;
-				}
-
-				if (!found)
-				{
-					g_object_unref(result_start);
-					g_object_unref(result_end);
-				}
-			}
-
-			g_free(text_to_search);
-		}
-		else
-		{
-			if (search_forward)
-			{
-				if (ianjuta_editor_search_forward (IANJUTA_EDITOR_SEARCH (search_box->priv->current_editor),
-					                               search_text, search_box->priv->case_sensitive,
-					                               search_start, search_end,
-					                               &result_start,
-					                               &result_end, NULL))
-				{
-					found = TRUE;
-				}
-			}
-			else
-			{
-				if (ianjuta_editor_search_backward (IANJUTA_EDITOR_SEARCH (search_box->priv->current_editor),
-					                                search_text, search_box->priv->case_sensitive,
-					                                search_end, search_start,
-					                                &result_start,
-					                                &result_end, NULL))
-				{
-					found = TRUE;
-				}
-			}
-		}
-	}
+	/* Try searching in current position */
+	found = editor_search (search_box->priv->current_editor,
+	                       search_text,
+	                       search_box->priv->case_sensitive,
+	                       search_forward,
+	                       search_box->priv->regex_mode,
+	                       search_start,
+	                       search_end,
+	                       &result_start,
+	                       &result_end);
 
 	if (found)
 	{
@@ -484,70 +510,22 @@ search_box_incremental_search (SearchBox* search_box, gboolean search_forward,
 		ianjuta_iterable_last (IANJUTA_ITERABLE (search_end), NULL);
 
 		/* Try to search again */
-		if (search_box->priv->regex_mode)
-		{
-			text_to_search = ianjuta_editor_get_text (search_box->priv->current_editor,
-			                                          IANJUTA_ITERABLE(search_start),
-			                                          IANJUTA_ITERABLE(search_end), NULL);
-
-			result = incremental_regex_search (search_text, text_to_search, &start_pos, &end_pos, search_forward);
-
-			start_pos += ianjuta_iterable_get_position(IANJUTA_ITERABLE(search_start), NULL);
-			end_pos += ianjuta_iterable_get_position(IANJUTA_ITERABLE(search_start), NULL);
-
-			if (result && start_pos >= 0)
-			{
-				result_start = IANJUTA_EDITOR_CELL (ianjuta_editor_get_start_position (search_box->priv->current_editor,
-				                                                                       NULL));
-				result_end = IANJUTA_EDITOR_CELL (ianjuta_editor_get_start_position (search_box->priv->current_editor,
-				                                                                     NULL));
-
-				if (ianjuta_iterable_set_position(IANJUTA_ITERABLE(result_start), start_pos, NULL) &&
-				    ianjuta_iterable_set_position(IANJUTA_ITERABLE(result_end), end_pos, NULL))
-				{
-					result_set = TRUE;
-				}
-
-				if (!result_set)
-				{
-					g_object_unref(result_start);
-					g_object_unref(result_end);
-				}
-			}
-		}
-		else
-		{
-			if (search_forward)
-			{
-				if (ianjuta_editor_search_forward (IANJUTA_EDITOR_SEARCH (search_box->priv->current_editor),
-				                                   search_text, search_box->priv->case_sensitive,
-				                                   search_start, search_end,
-				                                   &result_start,
-				                                   &result_end, NULL))
-				{
-					result_set = TRUE;
-				}
-			}
-			else
-			{
-				if (ianjuta_editor_search_backward (IANJUTA_EDITOR_SEARCH (search_box->priv->current_editor),
-				                                    search_text, search_box->priv->case_sensitive,
-				                                    search_end, search_start,
-				                                    &result_start,
-				                                    &result_end, NULL))
-				{
-					result_set = TRUE;
-				}
-			}
-		}
+		found = editor_search (search_box->priv->current_editor,
+		                       search_text,
+		                       search_box->priv->case_sensitive,
+		                       search_forward,
+		                       search_box->priv->regex_mode,
+		                       search_start,
+		                       search_end,
+		                       &result_start,
+		                       &result_end);
 
 		/* Check if successful */
-		if (result_set)
+		if (found)
 		{
 			if (ianjuta_iterable_compare (IANJUTA_ITERABLE (result_start),
 			                              real_start, NULL) != 0)
 			{
-				found = TRUE;
 				anjuta_status_pop (search_box->priv->status);
 				if (search_forward)
 				{
@@ -562,6 +540,7 @@ search_box_incremental_search (SearchBox* search_box, gboolean search_forward,
 			}
 			else if (ianjuta_editor_selection_has_selection (selection, NULL))
 			{
+				found = FALSE;
 				anjuta_status_pop (search_box->priv->status);
 				if (search_forward)
 				{
@@ -574,6 +553,10 @@ search_box_incremental_search (SearchBox* search_box, gboolean search_forward,
 						                _("Search for \"%s\" reached top and was continued at the bottom but no new match was found."), search_text);
 				}
 			}
+			else
+			{
+				found = FALSE;
+			}
 		}
 	}
 
@@ -594,6 +577,77 @@ search_box_incremental_search (SearchBox* search_box, gboolean search_forward,
 	return found;
 }
 
+static gboolean
+highlight_in_background (SearchBox *search_box)
+{
+	gboolean found = FALSE;
+	
+	GTimer *timer = g_timer_new();
+
+	if (search_box->priv->start_highlight != NULL)
+	{
+		const gchar* search_text = gtk_entry_get_text (GTK_ENTRY (search_box->priv->search_entry));
+
+		do
+		{
+			IAnjutaEditorCell* result_start;
+			IAnjutaEditorCell* result_end;
+
+			found = editor_search (search_box->priv->current_editor,
+			                       search_text,
+			                       search_box->priv->case_sensitive,
+			                       TRUE,
+			                       search_box->priv->regex_mode,
+			                       search_box->priv->start_highlight,
+			                       search_box->priv->end_highlight,
+			                       &result_start,
+			                       &result_end);
+			if (found)
+			{
+				ianjuta_indicable_set(IANJUTA_INDICABLE(search_box->priv->current_editor), 
+				                      IANJUTA_ITERABLE (result_start), 
+				                      IANJUTA_ITERABLE (result_end),
+				                      IANJUTA_INDICABLE_IMPORTANT, NULL);
+				g_object_unref (result_start);
+				g_object_unref (search_box->priv->start_highlight);
+				search_box->priv->start_highlight = result_end;
+			}
+		}
+		while (found && g_timer_elapsed(timer, NULL) < CONTINUOUS_SEARCH_TIMEOUT);
+		g_timer_destroy (timer);
+	}
+
+	if (!found)
+	{
+		search_box->priv->idle_id = 0;
+		g_clear_object (&search_box->priv->start_highlight);
+		g_clear_object (&search_box->priv->end_highlight);
+	}
+
+	return found;
+}
+
+void
+search_box_highlight_all (SearchBox *search_box)
+{
+	if (!search_box->priv->current_editor)
+		return;
+
+	ianjuta_indicable_clear(IANJUTA_INDICABLE(search_box->priv->current_editor), NULL);
+	if (search_box->priv->start_highlight != NULL) g_object_unref (search_box->priv->start_highlight);
+	if (search_box->priv->end_highlight != NULL) g_object_unref (search_box->priv->end_highlight);
+	search_box->priv->start_highlight = IANJUTA_EDITOR_CELL (ianjuta_editor_get_start_position (search_box->priv->current_editor, NULL));
+	search_box->priv->end_highlight = IANJUTA_EDITOR_CELL (ianjuta_editor_get_end_position (search_box->priv->current_editor, NULL));
+
+	if (search_box->priv->idle_id == 0)
+	{
+		search_box->priv->idle_id = g_idle_add_full(G_PRIORITY_DEFAULT_IDLE,
+		                                            (GSourceFunc)highlight_in_background,
+		                                            search_box,
+		                                            NULL);
+	}
+}
+
 void 
 search_box_clear_highlight (SearchBox * search_box)
 {
@@ -601,7 +655,6 @@ search_box_clear_highlight (SearchBox * search_box)
 		return;
 
 	ianjuta_indicable_clear(IANJUTA_INDICABLE(search_box->priv->current_editor), NULL);	
-	search_box->priv->highlight_complete = FALSE;
 }
 
 void 
@@ -617,7 +670,12 @@ search_box_toggle_highlight (SearchBox * search_box, gboolean status)
 	if (!status)
 	{
 		ianjuta_indicable_clear(IANJUTA_INDICABLE(search_box->priv->current_editor), NULL);
-		search_box->priv->highlight_complete = FALSE;
+		g_clear_object (&search_box->priv->start_highlight);
+		g_clear_object (&search_box->priv->end_highlight);
+	}
+	else
+	{
+		search_box_highlight_all (search_box);
 	}
 }
 
@@ -630,7 +688,7 @@ search_box_toggle_case_sensitive (SearchBox * search_box, gboolean status)
 	                             status);
 	                               
 	search_box->priv->case_sensitive = status;
-	search_box_clear_highlight(search_box);
+	if (search_box->priv->highlight_all) search_box_highlight_all (search_box);
 }
 
 void
@@ -643,57 +701,7 @@ search_box_toggle_regex (SearchBox * search_box, gboolean status)
 	                             status);
 	
 	search_box->priv->regex_mode = status;
-	search_box_clear_highlight(search_box);
-
-}
-
-void
-search_box_search_highlight_all (SearchBox * search_box, gboolean search_forward)
-{
-	IAnjutaEditorCell * highlight_start;
-	IAnjutaEditorSelection * selection;
-	gboolean entry_found;
-	
-	highlight_start = NULL;
-	ianjuta_indicable_clear(IANJUTA_INDICABLE(search_box->priv->current_editor), NULL);
-
-	/* Search through editor and highlight instances of search_entry */
-	while ((entry_found = search_box_incremental_search (search_box, search_forward, TRUE)) == TRUE)
-	{
-		IAnjutaEditorCell * result_begin, * result_end;
-		selection = IANJUTA_EDITOR_SELECTION (search_box->priv->current_editor);
-
-		result_begin = 
-			IANJUTA_EDITOR_CELL (ianjuta_editor_selection_get_start (selection, NULL));	
-		result_end = 
-			IANJUTA_EDITOR_CELL (ianjuta_editor_selection_get_end (selection, NULL));
-
-		if (!highlight_start)
-		{
-			highlight_start = 
-				IANJUTA_EDITOR_CELL (ianjuta_iterable_clone (IANJUTA_ITERABLE (result_begin), NULL));
-		} 
-		else if (ianjuta_iterable_compare (IANJUTA_ITERABLE (result_begin),
-											IANJUTA_ITERABLE (highlight_start), NULL) == 0)
-		{
-			g_object_unref (result_begin);
-			g_object_unref (result_end);
-			g_object_unref (highlight_start);
-			highlight_start = NULL;
-			break;
-		}
-
-		ianjuta_indicable_set(IANJUTA_INDICABLE(search_box->priv->current_editor), 
-								IANJUTA_ITERABLE (result_begin), 
-								IANJUTA_ITERABLE (result_end),
-								IANJUTA_INDICABLE_IMPORTANT, NULL);
-		g_object_unref (result_begin);
-		g_object_unref (result_end);
-	}
-	if (highlight_start)
-		g_object_unref (highlight_start);
-	search_box->priv->highlight_complete = TRUE;
-
+	if (search_box->priv->highlight_all) search_box_highlight_all (search_box);
 }
 
 static void
@@ -703,7 +711,7 @@ on_search_box_entry_changed (GtkWidget * widget, SearchBox * search_box)
 	{
 		GtkEntryBuffer* buffer = gtk_entry_get_buffer (GTK_ENTRY(widget));
 		if (gtk_entry_buffer_get_length (buffer))
-			search_box_incremental_search (search_box, TRUE, TRUE);
+			search_box_incremental_search (search_box, TRUE, FALSE, TRUE);
 		else
 		{
 			/* clear selection */
@@ -716,33 +724,20 @@ on_search_box_entry_changed (GtkWidget * widget, SearchBox * search_box)
 			                              FALSE, NULL);
 		}
 	}
+
+	if (search_box->priv->highlight_all) search_box_highlight_all (search_box);
 }
 
 static void
 search_box_forward_search (SearchBox * search_box, GtkWidget* widget)
 {
-	if (search_box->priv->highlight_all && !search_box->priv->highlight_complete)
-	{
-		search_box_search_highlight_all (search_box, TRUE);
-	}
-	else
-	{
-		search_box_incremental_search (search_box, TRUE, TRUE);
-	}
-
+	search_box_incremental_search (search_box, TRUE, TRUE, TRUE);
 }
 
 static void
 on_search_box_backward_search (GtkWidget * widget, SearchBox * search_box)
 {
-	if (search_box->priv->highlight_all && !search_box->priv->highlight_complete)
-	{
-		search_box_search_highlight_all (search_box, FALSE);
-	}
-	else
-	{
-		search_box_incremental_search (search_box, FALSE, TRUE);
-	}
+	search_box_incremental_search (search_box, FALSE, TRUE, TRUE);
 }
 
 static gboolean
@@ -768,7 +763,7 @@ search_box_replace (SearchBox * search_box, GtkWidget * widget,
 			gchar * replacement_text;
 			gint start_pos, end_pos;
 			GError * err = NULL;
-			gboolean result = incremental_regex_search (search_text, selection_text, &start_pos, &end_pos, TRUE);
+			gboolean result = search_regex_in_text (search_text, selection_text, TRUE, &start_pos, &end_pos);
 				
 			if (result)
 			{
@@ -893,7 +888,7 @@ on_replace_all_activated (GtkWidget* widget, SearchBox* search_box)
 	
 	/* Replace all instances of search_entry with replace_entry text */
 	ianjuta_document_begin_undo_action (IANJUTA_DOCUMENT (search_box->priv->current_editor), NULL);
-	while (search_box_incremental_search (search_box, TRUE, FALSE))
+	while (search_box_incremental_search (search_box, TRUE, TRUE, FALSE))
 	{
 		search_box_replace (search_box, widget, FALSE);
 	}
@@ -993,8 +988,12 @@ search_box_init (SearchBox *search_box)
 	search_box->priv->regex_mode = FALSE;
 	search_box->priv->highlight_all = FALSE;
 	search_box->priv->case_sensitive = FALSE;
-	search_box->priv->highlight_complete = FALSE;
 
+	/* Highlight iterator */
+	search_box->priv->start_highlight = NULL;
+	search_box->priv->end_highlight = NULL;
+	search_box->priv->idle_id = 0;
+	
 	/* Initialize search_box grid */
 	search_box->priv->grid = gtk_grid_new();
 	gtk_orientable_set_orientation (GTK_ORIENTABLE (search_box->priv->grid), 
@@ -1060,6 +1059,11 @@ search_box_init (SearchBox *search_box)
 static void
 search_box_finalize (GObject *object)
 {
+	SearchBox *search_box = SEARCH_BOX (object);
+
+	if (search_box->priv->idle_id) g_source_remove (search_box->priv->idle_id);
+	if (search_box->priv->start_highlight) g_object_unref (search_box->priv->start_highlight);
+	if (search_box->priv->end_highlight) g_object_unref (search_box->priv->end_highlight);
 
 	G_OBJECT_CLASS (search_box_parent_class)->finalize (object);
 }
