@@ -77,6 +77,10 @@ struct _Git
 	AnjutaDockPane *remotes_pane;
 	AnjutaDockPane *stash_pane;
 
+	/* Popup menu action groups */
+	gint uiid;
+	GtkActionGroup *status_menu_group;
+
 	/* List commands for various panes. 
 	 * Keep them in the plugin so that the commands have the most direct
 	 * way of handling project (working directory) changes */
